@@ -1364,7 +1364,7 @@ Tetris::endOfGame()
 	if (scoreFrame->getScore() > 0) 
 	{
 		int pos = high_scores->add (scoreFrame->getScore());
-		high_scores->show (pos);
+		high_scores->show (GTK_WINDOW (w), pos);
 	}
 
 	field->setUseTarget (false);
@@ -1408,6 +1408,8 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->preview->previewBlock(blocknr_next, rot_next, color_next);
 	gtk_widget_queue_draw(t->preview->getWidget());
 
+	gtk_action_set_visible(t->pause_action, TRUE);
+	gtk_action_set_visible(t->resume_action, FALSE);
 	gtk_action_set_sensitive(t->pause_action, TRUE);
 	gtk_action_set_sensitive(t->end_game_action, TRUE);
 	gtk_action_set_sensitive(t->preferences_action, FALSE);
@@ -1439,14 +1441,16 @@ Tetris::gameAbout(GtkAction *action, void *d)
 
 	const gchar * const documenters[] = { "Angela Boyle", NULL };
 
+	gchar *license = games_get_license (_("Gnometris"));
+
 	gtk_show_about_dialog (GTK_WINDOW (t->getWidget()),
 			       "name", _("Gnometris"),
 			       "version", VERSION,
 			       "comments", _("Written for my wife, Matylda\n"
 					     "Send comments and bug reports to: \n"
 					     "janusz.gorycki@intel.com"),
-			       "copyright", "Copyright \xc2\xa9 1999-2006 J. Marcin Gorycki",
-			       "license", "GPL 2+",
+			       "copyright", "Copyright \xc2\xa9 1999-2007 J. Marcin Gorycki",
+			       "license", license,
 			       "authors", authors,
 			       "documenters", documenters,				
 			       "translator_credits", _("translator-credits"),
@@ -1454,6 +1458,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 			       "website", "http://www.gnome.org/projects/gnome-games/",
 			       "wrap-license", TRUE,
 			       NULL);
+	g_free (license);
 
 	return TRUE;
 }
